@@ -5,15 +5,24 @@ import click
 from termcolor import colored
 from punish.style import AbstractStyle
 from pypans.file import Template
-from pypans.project import NEW_LINE, Project, User  # noqa: I100
+from pypans.project import Line, Project, User  # noqa: I100
 
 
-def _write_as_colored(string: str, color: str) -> int:
-    """Writes data into colored output.
+class _Output(AbstractStyle):
+    """A command line output."""
 
-    Returns number of characters to write.
-    """
-    return sys.stdout.write(f"{colored(string, color)}{NEW_LINE}")
+    def __init__(self, color: str) -> None:
+        self._color: str = color
+
+    def write(self, string: str) -> int:
+        """Writes data into colored output.
+
+        Args:
+            string (str): given string.
+
+        Returns number of characters to write.
+        """
+        return sys.stdout.write(f"{colored(string, self._color)}{Line.NEW.value}")
 
 
 class __Environment(AbstractStyle):
@@ -23,6 +32,7 @@ class __Environment(AbstractStyle):
         self._name = name
         self._user = user
         self._project: Project = Project(name, user)
+        self.__red_out: _Output = _Output(color="red")
 
     def setup_project(self) -> None:
         """Builds given project."""
@@ -55,8 +65,8 @@ class __Environment(AbstractStyle):
                 )
             )
         else:
-            _write_as_colored(
-                string=f">>> 🚨 Setup with git is skipped for `{self._name}` project 🚨", color="red"
+            self.__red_out.write(
+                string=f">>> 🚨 Setup with git is skipped for `{self._name}` project 🚨",
             )
 
     def install_requirements(self) -> None:
@@ -66,11 +76,13 @@ class __Environment(AbstractStyle):
             os.system(command=f"pip install -r {file}")
             if file is Template.REQUIREMENTS:
                 os.system(command=f"pip freeze > {file}")
-            else:
+            elif file is Template.DEV_REQUIREMENTS:
                 os.system(
                     "pip freeze | egrep "
                     f"'pytest|pdbpp|python|pydoc|black|pylint|mypy|flake8|cov|manifest' > {file}"
                 )
+            else:
+                raise ValueError(f"'{file}' template is not supported!")
 
         install: str = input(
             colored(
@@ -83,18 +95,16 @@ class __Environment(AbstractStyle):
             install_from(file=Template.REQUIREMENTS)
             install_from(file=Template.DEV_REQUIREMENTS)
         else:
-            _write_as_colored(
+            self.__red_out.write(
                 string=f">>> 🚨 Dependencies installation is skipped for `{self._name}` project 🚨",
-                color="red",
             )
 
 
 def __build_environment() -> None:
     """Builds fully-fledged environment."""
-    _write_as_colored(
-        string=">>> 🥘 Welcome to `pypan` python project builder utility 🥘", color="green"
-    )
-    _write_as_colored(string=">>>", color="green")
+    green_output: _Output = _Output(color="green")
+    green_output.write(string=">>> 🥘 Welcome to `pypan` python project builder utility 🥘",)
+    green_output.write(string=">>>")
     name: str = input(colored(">>> Please name your application (e.g bomber): ", "green"))
     environment: __Environment = __Environment(
         name=name,
@@ -106,9 +116,9 @@ def __build_environment() -> None:
     environment.setup_project()
     environment.setup_git()
     environment.install_requirements()
-    _write_as_colored(string=">>>", color="green")
-    _write_as_colored(
-        string=f">>> 🐍 Successfully created fresh `{name}` python project 🐍", color="magenta"
+    green_output.write(string=">>>")
+    _Output(color="magenta").write(
+        string=f">>> 🐍 Successfully created fresh `{name}` python project 🐍"
     )
 
 
@@ -119,14 +129,14 @@ def __build_environment() -> None:
     is_flag=True,
     help=f"""
 
-    Starts python project composer:{NEW_LINE}
-      >>> Configure project packaging for `python`{NEW_LINE}
-      >>> Configure testing environment with `pytest`{NEW_LINE}
-      >>> Configure static code analysis and CI tools{NEW_LINE}
-      >>> Configure readme and changelog{NEW_LINE}
-      >>> Configure project requirements{NEW_LINE}
-      >>> Configure `git` (optional){NEW_LINE}
-      >>> Install python dependencies (optional){NEW_LINE}
+    Starts python project composer:{Line.NEW.value}
+      >>> Configure project packaging for `python`{Line.NEW.value}
+      >>> Configure testing environment with `pytest`{Line.NEW.value}
+      >>> Configure static code analysis and CI tools{Line.NEW.value}
+      >>> Configure readme and changelog{Line.NEW.value}
+      >>> Configure project requirements{Line.NEW.value}
+      >>> Configure `git` (optional){Line.NEW.value}
+      >>> Install python dependencies (optional){Line.NEW.value}
     """,
 )
 def easypan(start: bool) -> None:
